"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("./config");
const Server_1 = require("./Server");
const utils_1 = require("./utils");
const logger = (0, utils_1.getLogger)('index');
const server = new Server_1.Server(config_1.config);
server.start().catch(error => {
    logger.error(error);
    process.exit(1);
});
process.on('SIGINT', () => __awaiter(void 0, void 0, void 0, function* () {
    logger.info('Received "SIGINT" signal. Exiting.');
    try {
        yield server.stop();
    }
    catch (error) {
        logger.error(error);
    }
    process.exit();
}));
process.on('SIGTERM', () => __awaiter(void 0, void 0, void 0, function* () {
    logger.info('Received "SIGTERM" signal. Exiting.');
    try {
        yield server.stop();
    }
    catch (error) {
        logger.error(error);
    }
    process.exit();
}));
process.on('uncaughtException', error => {
    console.error(`Uncaught exception: ${error.message}`, error);
});
process.on('unhandledRejection', (reason, promise) => {
    console.error('Unhandled rejection at:', promise, 'reason:', reason);
});
//# sourceMappingURL=index.js.map