"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mainRoute = void 0;
const express_1 = require("express");
const http_status_codes_1 = require("http-status-codes");
const utils_1 = require("../utils");
const packagesRoute_1 = require("./packagesRoute");
const logger = (0, utils_1.getLogger)('routes/mainRoute');
const router = (0, express_1.Router)();
const repositoryUrl = 'https://github.com/ffflorian/pkgsource';
function mainRoute() {
    return router
        .get('/', (req, res) => {
        logger.info('Got request for main page');
        if ('unpkg' in req.query && req.query.unpkg !== 'false') {
            const redirectUrl = `${packagesRoute_1.unpkgBase}/pkgsource@latest/`;
            if ('raw' in req.query && req.query.raw !== 'false') {
                logger.info(`Returning raw unpkg info for main page: "${redirectUrl}" ...`);
                return res.json({
                    code: http_status_codes_1.StatusCodes.OK,
                    url: redirectUrl,
                });
            }
            logger.info(`Redirecting main page to unpkg: "${redirectUrl}" ...`);
            return res.redirect(http_status_codes_1.StatusCodes.MOVED_TEMPORARILY, redirectUrl);
        }
        if ('raw' in req.query && req.query.raw !== 'false') {
            logger.info(`Returning raw info for main page: "${repositoryUrl}" ...`);
            return res.json({
                code: http_status_codes_1.StatusCodes.OK,
                url: repositoryUrl,
            });
        }
        logger.info(`Redirecting main page to "${repositoryUrl}" ...`);
        return res.redirect(repositoryUrl);
    })
        .get('/robots.txt', (_, res) => {
        return res.contentType('text/plain').send('User-agent: *\nDisallow: /');
    })
        .get('/favicon.ico', (_, res) => {
        return res.status(http_status_codes_1.StatusCodes.NOT_FOUND).send({
            code: http_status_codes_1.StatusCodes.NOT_FOUND,
            message: 'Not found',
        });
    });
}
exports.mainRoute = mainRoute;
//# sourceMappingURL=mainRoute.js.map