"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.packagesRoute = exports.unpkgBase = void 0;
const express_1 = require("express");
const url_1 = require("url");
const http_status_codes_1 = require("http-status-codes");
const RepositoryParser_1 = require("../RepositoryParser");
const utils_1 = require("../utils");
const logger = (0, utils_1.getLogger)('routes/packagesRoute');
const router = (0, express_1.Router)();
const packageNameRegex = new RegExp('^\\/((?:@[^@/]+/)?[^@/]+)(?:@([^@/]+))?\\/?$');
exports.unpkgBase = new url_1.URL('https://unpkg.com/browse');
function packagesRoute() {
    return router.get(packageNameRegex, (request, response) => __awaiter(this, void 0, void 0, function* () {
        var _a, _b;
        const packageName = ((_a = request.params[0]) === null || _a === void 0 ? void 0 : _a.trim()) || 'pkgsource';
        const version = ((_b = request.params[1]) === null || _b === void 0 ? void 0 : _b.trim()) || 'latest';
        let errorCode;
        let errorMessage;
        logger.info(`Got request for package "${packageName}" (version "${version}").`);
        if ((0, utils_1.queryParameterExists)(request, 'unpkg')) {
            const redirectUrl = `${exports.unpkgBase}/${packageName}@${version}/`;
            if (!(0, utils_1.validateUrl)(redirectUrl)) {
                return response
                    .status(http_status_codes_1.StatusCodes.BAD_REQUEST)
                    .json({ code: http_status_codes_1.StatusCodes.BAD_REQUEST, message: `Invalid URL: ${redirectUrl}` });
            }
            if ((0, utils_1.queryParameterExists)(request, 'raw')) {
                logger.info(`Returning raw unpkg info for "${packageName}": "${redirectUrl}" ...`);
                return response.json({
                    code: http_status_codes_1.StatusCodes.OK,
                    url: redirectUrl,
                });
            }
            logger.info(`Redirecting package "${packageName}" to unpkg: "${redirectUrl}" ...`);
            return response.redirect(http_status_codes_1.StatusCodes.MOVED_TEMPORARILY, redirectUrl);
        }
        const parseResult = yield (0, RepositoryParser_1.getPackageUrl)(packageName, version);
        switch (parseResult.status) {
            case RepositoryParser_1.ParseStatus.SUCCESS: {
                const redirectSite = parseResult.url;
                if ((0, utils_1.queryParameterExists)(request, 'raw')) {
                    logger.info(`Returning raw info for "${packageName}": "${redirectSite}" ...`);
                    return response.json({
                        code: http_status_codes_1.StatusCodes.OK,
                        url: redirectSite,
                    });
                }
                logger.info(`Redirecting package "${packageName}" to "${redirectSite}" ...`);
                return response.redirect(http_status_codes_1.StatusCodes.MOVED_TEMPORARILY, redirectSite);
            }
            case RepositoryParser_1.ParseStatus.INVALID_PACKAGE_NAME: {
                errorCode = http_status_codes_1.StatusCodes.UNPROCESSABLE_ENTITY;
                errorMessage = 'Invalid package name';
                break;
            }
            case RepositoryParser_1.ParseStatus.INVALID_URL:
            case RepositoryParser_1.ParseStatus.NO_URL_FOUND: {
                errorCode = http_status_codes_1.StatusCodes.NOT_FOUND;
                errorMessage = `No source URL found. Please visit https://www.npmjs.com/package/${packageName}.`;
                break;
            }
            case RepositoryParser_1.ParseStatus.PACKAGE_NOT_FOUND: {
                errorCode = http_status_codes_1.StatusCodes.NOT_FOUND;
                errorMessage = 'Package not found';
                break;
            }
            case RepositoryParser_1.ParseStatus.VERSION_NOT_FOUND: {
                errorCode = http_status_codes_1.StatusCodes.NOT_FOUND;
                errorMessage = 'Version not found';
                break;
            }
            case RepositoryParser_1.ParseStatus.SERVER_ERROR:
            default: {
                errorCode = http_status_codes_1.StatusCodes.INTERNAL_SERVER_ERROR;
                errorMessage = 'Internal server error';
                break;
            }
        }
        return response.status(errorCode).json({ code: errorCode, message: errorMessage });
    }));
}
exports.packagesRoute = packagesRoute;
//# sourceMappingURL=packagesRoute.js.map